@@ -69,6 +69,18 @@ class Position:
         self._phi: float = radians(phi) if indegrees else phi
         self.indegrees: bool = indegrees
 
+    def __str__(self):
+        """Represent Position object information as a string.
+
+        Returns
+        -------
+        str
+            Position object string representation.
+        """
+        if self.indegrees:
+            return f"Position({', '.join((f'{k}: {v:.4f}' for k, v in self.asdict.items()))})"
+        return f"Position({', '.join((f'{k}: {degrees(v):.4f}' for k, v in self.asdict.items()))})"
+
     @classmethod
     def asdegrees(cls, pos: "Position") -> "Position":
         """Create new Position object with angles in degrees.
@@ -392,4 +404,4 @@ def get_q_phi(pos: Position) -> np.ndarray:
     y = np.array([[0], [1], [0]])
     q_lab = (NU @ DELTA - I) @ y
     # Transform this into the phi frame.
-    return inv(PHI) @ inv(CHI) @ inv(ETA) @ inv(MU) @ q_lab
+    return np.array(inv(PHI) @ inv(CHI) @ inv(ETA) @ inv(MU) @ q_lab)
