@@ -10,7 +10,7 @@ import uuid
 from copy import deepcopy
 from itertools import product
 from math import acos, asin, cos, degrees, pi, radians, sin
-from typing import List, Optional, Sequence, Tuple, Union
+from typing import Any, Dict, List, Optional, Sequence, Tuple, Union
 
 import numpy as np
 from diffcalc.hkl.geometry import Position, get_q_phi, get_rotation_matrices
@@ -42,7 +42,7 @@ class ReferenceVector:
     Attributes
     ----------
     n_ref: Tuple[float, float, float]
-        tuple with vector coordinates
+        Tuple with vector coordinates.
     rlv: bool
         Flag indicating if coordinates are in reciprocal or
         laboratory coordinate system.
@@ -52,9 +52,9 @@ class ReferenceVector:
     Methods
     -------
     get_array(UB: Optional[np.ndarray] = None) -> np.ndarray
-        Return reference vector as 3x1 NumPy array
+        Return reference vector as 3x1 NumPy array.
     set_array(n_ref: np.ndarray) -> Tuple[float, float, float]
-        Set reference vector coordinates from 3x1 NumPy array
+        Set reference vector coordinates from 3x1 NumPy array.
     """
 
     n_ref: Tuple[float, float, float]
@@ -71,8 +71,8 @@ class ReferenceVector:
         ----------
         UB: np.ndarray, optional
             UB matrix as (3, 3) NumPy array object. Use UB matrix to convert
-            coordinates between reciprocal and laboratory coordinate systems
-            (default: None, do not convert coordinates into the alternative system)
+            coordinates between reciprocal and laboratory coordinate systems.
+            (default: None, do not convert coordinates into the alternative system).
 
         Returns
         -------
@@ -89,7 +89,7 @@ class ReferenceVector:
             return n_ref_array
         if not isinstance(UB, np.ndarray):
             raise DiffcalcException(
-                "Invalid input parameter. UB must be a NumPy array object"
+                "Invalid input parameter. UB must be a NumPy array object."
             )
         elif UB.shape != (3, 3):
             raise DiffcalcException(
@@ -99,7 +99,8 @@ class ReferenceVector:
             n_ref_new = UB @ n_ref_array
         else:
             n_ref_new = inv(UB) @ n_ref_array
-        return n_ref_new / norm(n_ref_new)
+
+        return np.array(n_ref_new / float(norm(n_ref_new)))
 
     def set_array(self, n_ref: np.ndarray) -> None:
         """Set reference vector coordinates from NumPy array.
@@ -116,7 +117,7 @@ class ReferenceVector:
         Raises
         ------
         DiffcalcException
-            If input parameter is not (3, 1) NumPy array
+            If input parameter is not (3, 1) NumPy array.
 
         """
         if not isinstance(n_ref, np.ndarray):
@@ -130,6 +131,19 @@ class ReferenceVector:
         (r1, r2, r3) = tuple(n_ref.T[0].tolist())
         self.n_ref = (r1, r2, r3)
 
+    @property
+    def asdict(self) -> Dict[str, Any]:
+        """Serialise the object into a JSON compatible dictionary.
+
+        Returns
+        -------
+        Dict[str, Any]
+            Dictionary containing properties of this class. Can
+            be unpacked directly by calling ReferenceVector(**resulting_dict).
+
+        """
+        return self.__dict__.copy()
+
 
 class UBCalculation:
     """Class containing information required for for UB matrix calculation.
@@ -149,9 +163,9 @@ class UBCalculation:
     surface: ReferenceVector
         Object representing surface normal vector.
     U: np.ndarray
-        U matrix as a NumPy array
+        U matrix as a NumPy array.
     UB: np.ndarray
-        UB matrix as a NumPy array
+        UB matrix as a NumPy array.
     """
 
     def __init__(self, name: Optional[str] = None) -> None:
@@ -407,7 +421,7 @@ class UBCalculation:
         Parameters
         ----------
         name: str
-            Crystal name
+            Crystal name.
         system: Optional[float], default = None
             Crystal lattice type.
         a: Optional[float], default = None
@@ -425,7 +439,7 @@ class UBCalculation:
         """
         if not isinstance(name, str):
             raise TypeError("Invalid crystal name.")
-        shortform = tuple(
+        shortform: Tuple[Any, ...] = tuple(
             val for val in (system, a, b, c, alpha, beta, gamma) if val is not None
         )
         if not shortform:
@@ -449,17 +463,17 @@ class UBCalculation:
                 raise TypeError(
                     "Invalid number of input parameters to set unit lattice."
                 )
-            fullform = (system,) + shortform
+            fullform: Tuple[Any, ...] = (system,) + shortform
+            self.crystal = Crystal(name, *fullform)
         else:
             if not isinstance(shortform[0], str):
                 raise TypeError("Invalid unit cell parameters specified.")
-            fullform = shortform
+            self.crystal = Crystal(name, *shortform)
         if self.name is None:
             raise DiffcalcException(
                 "Cannot set lattice until a UBCalcaluation has been started "
-                "with newubcalc"
+                "with newub."
             )
-        self.crystal = Crystal(name, *fullform)
 
     ### Reference vector ###
     @property
@@ -544,13 +558,13 @@ class UBCalculation:
         Parameters
         ----------
         hkl : Tuple[float, float, float]
-            hkl index of the reflection
+            hkl index of the reflection.
         position: Position
-            list of diffractometer angles in internal representation in degrees
+            List of diffractometer angles in internal representation in degrees.
         energy : float
-            energy of the x-ray beam
+            Energy of the x-ray beam.
         tag : Optional[str], default = None
-            identifying tag for the reflection
+            Identifying tag for the reflection.
         """
         if self.reflist is None:
             raise DiffcalcException("No UBCalculation loaded")
@@ -572,15 +586,15 @@ class UBCalculation:
         Parameters
         ----------
         idx : Union[str, int]
-            index or tag of the reflection to be changed
+            Index or tag of the reflection to be changed.
         hkl : Tuple[float, float, float]
-            hkl index of the reflection
+            hkl index of the reflection.
         position: Position
-            list of diffractometer angles in internal representation in degrees
+            List of diffractometer angles in internal representation in degrees.
         energy : float
-            energy of the x-ray beam
+            Energy of the x-ray beam.
         tag : Optional[str], default = None
-            identifying tag for the reflection
+            Identifying tag for the reflection.
         """
         if self.reflist is None:
             raise DiffcalcException("No UBCalculation loaded")
@@ -595,7 +609,7 @@ class UBCalculation:
         Parameters
         ----------
         idx : Union[str, int]
-            index or tag of the reflection
+            Index or tag of the reflection.
         """
         return self.reflist.get_reflection(idx)
 
@@ -621,7 +635,8 @@ class UBCalculation:
         Parameters
         ----------
         tag : str
-            identifying tag for the reflection
+            Identifying tag for the reflection.
+
         Returns
         -------
         int:
@@ -637,7 +652,7 @@ class UBCalculation:
         Parameters
         ----------
         idx : str or int
-            index or tag of the deleted reflection
+            Index or tag of the deleted reflection.
         """
         self.reflist.remove_reflection(idx)
 
@@ -647,9 +662,9 @@ class UBCalculation:
         Parameters
         ----------
         idx1 : str or int
-            index or tag of the first reflection to be swapped
+            Index or tag of the first reflection to be swapped.
         idx2 : str or int
-            index or tag of the second reflection to be swapped
+            Index or tag of the second reflection to be swapped.
         """
         self.reflist.swap_reflections(idx1, idx2)
 
@@ -664,13 +679,13 @@ class UBCalculation:
         Parameters
         ----------
         hkl : :obj:`tuple` of numbers
-            hkl index of the reference orientation
+            hkl index of the reference orientation.
         xyz : :obj:`tuple` of numbers
-            xyz coordinate of the reference orientation
+            xyz coordinate of the reference orientation.
         position: :obj:`list` or :obj:`tuple` of numbers
-            list of diffractometer angles in internal representation in degrees
+            List of diffractometer angles in internal representation in degrees.
         tag : str
-            identifying tag for the reflection
+            Identifying tag for the reflection.
         """
         if self.orientlist is None:
             raise DiffcalcException("No UBCalculation loaded")
@@ -687,15 +702,15 @@ class UBCalculation:
         Parameters
         ----------
         idx : str or int
-            index or tag of the orientation to be changed
+            Index or tag of the orientation to be changed.
         hkl : :obj:`tuple` of numbers
-            h index of the reference orientation
+            h index of the reference orientation.
         xyz : :obj:`tuple` of numbers
-            x coordinate of the reference orientation
+            x coordinate of the reference orientation.
         position: :obj:`list` or :obj:`tuple` of numbers
-            list of diffractometer angles in internal representation in degrees
+            List of diffractometer angles in internal representation in degrees.
         tag : str
-            identifying tag for the reflection
+            Identifying tag for the reflection.
         """
         if self.orientlist is None:
             raise DiffcalcException("No UBCalculation loaded")
@@ -712,7 +727,7 @@ class UBCalculation:
         Parameters
         ----------
         idx : str or int
-            index or tag of the reference orientation
+            Index or tag of the reference orientation.
         """
         return self.orientlist.get_orientation(idx)
 
@@ -738,11 +753,12 @@ class UBCalculation:
         Parameters
         ----------
         tag : str
-            identifying tag for the orientation
+            Identifying tag for the orientation.
+
         Returns
         -------
         int:
-            Reference orientation index
+            Reference orientation index.
         """
         if tag is None:
             raise IndexError("Orientations tag is None")
@@ -754,7 +770,7 @@ class UBCalculation:
         Parameters
         ----------
         idx : str or int
-            index or tag of the deleted orientation
+            Index or tag of the deleted orientation.
         """
         self.orientlist.remove_orientation(idx)
 
@@ -764,9 +780,9 @@ class UBCalculation:
         Parameters
         ----------
         idx1 : str or int
-            index or tag of the first orientation to be swapped
+            Index or tag of the first orientation to be swapped.
         idx2 : str or int
-            index or tag of the second orientation to be swapped
+            Index or tag of the second orientation to be swapped.
         """
         self.orientlist.swap_orientations(idx1, idx2)
 
@@ -801,7 +817,7 @@ class UBCalculation:
         Raises
         ------
         ValueError
-            if collection isn't (3, 3) shape.
+            If collection isn't (3, 3) shape.
         """
         m = np.array(matrix, dtype=float)
         if len(m.shape) != 2 or m.shape[0] != 3 or m.shape[1] != 3:
@@ -842,7 +858,7 @@ class UBCalculation:
         Raises
         ------
         ValueError
-            if collection isn't (3, 3) shape.
+            If collection isn't (3, 3) shape.
         """
         m = np.array(matrix, dtype=float)
         if len(m.shape) != 2 or m.shape[0] != 3 or m.shape[1] != 3:
@@ -912,7 +928,7 @@ class UBCalculation:
                 ref1 = self.get_orientation(idx1)
             except Exception:
                 raise DiffcalcException(
-                    "Cannot find first reflection or orientation with index %s"
+                    "Cannot find first reflection or orientation with index %s."
                     % str(idx1)
                 )
         try:
@@ -922,7 +938,7 @@ class UBCalculation:
                 ref2 = self.get_orientation(idx2)
             except Exception:
                 raise DiffcalcException(
-                    "Cannot find second reflection or orientation with index %s"
+                    "Cannot find second reflection or orientation with index %s."
                     % str(idx2)
                 )
         return ref1, ref2
@@ -1006,7 +1022,7 @@ class UBCalculation:
             refl = self.get_reflection(idx)
         except IndexError:
             raise DiffcalcException(
-                "One reflection is required to calculate a u matrix"
+                "One reflection is required to calculate a u matrix."
             )
 
         h = np.array([[refl.h], [refl.k], [refl.l]])
@@ -1024,9 +1040,9 @@ class UBCalculation:
         rotation_angle = acos(cos_rotation_angle)
 
         uvw = rotation_axis.T.tolist()[0]  # TODO: cleanup
-        print(f"resulting U angle: {degrees(rotation_angle):.5f} deg")
+        print(f"Resulting U angle: {degrees(rotation_angle):.5f} deg.")
         u_repr = ", ".join(["% .5f" % el for el in uvw])
-        print("resulting U axis direction: [%s]" % u_repr)
+        print("Resulting U axis direction: [%s]." % u_repr)
 
         u, v, w = uvw
         rcos = cos(rotation_angle)
@@ -1086,9 +1102,6 @@ class UBCalculation:
         Tuple[np.ndarray, Tuple[str, float, float, float, float, float, float]]
             Refined U matrix as NumPy array and refined crystal lattice parameters.
         """
-        """
-        refineub {[h k l]} {pos} -- refine unit cell dimensions and U matrix to match diffractometer angles for a given hkl value
-        """
         scale, lat = self._rescale_unit_cell(hkl, position, wavelength)
         if scale and refine_lattice:
             self.set_lattice(*lat)
@@ -1200,7 +1213,7 @@ class UBCalculation:
         a1 = cross3(b2.T, b3.T) * 2 * pi / V
         a2 = cross3(b3.T, b1.T) * 2 * pi / V
         a3 = cross3(b1.T, b2.T) * 2 * pi / V
-        ax, bx, cx = norm(a1), norm(a2), norm(a3)
+        ax, bx, cx = float(norm(a1)), float(norm(a2)), float(norm(a3))
         alpha = acos(dot3(a2, a3) / (bx * cx))
         beta = acos(dot3(a1, a3) / (ax * cx))
         gamma = acos(dot3(a1, a2) / (ax * bx))
@@ -1231,7 +1244,9 @@ class UBCalculation:
             rotation_angle = 0.0
         else:
             rotation_axis = rotation_axis / norm(rotation_axis)
-            cos_rotation_angle = bound(dot3(self.surf_nphi, surf_rot) / norm(surf_rot))
+            cos_rotation_angle = bound(
+                float(dot3(self.surf_nphi, surf_rot) / norm(surf_rot))
+            )
             rotation_angle = acos(cos_rotation_angle)
         return rotation_angle, rotation_axis
 
@@ -1263,7 +1278,9 @@ class UBCalculation:
             return None, None
         axis = axis / norm(axis)
         try:
-            miscut = acos(bound(dot3(q_vec, hkl_nphi) / (norm(q_vec) * norm(hkl_nphi))))
+            miscut = acos(
+                bound(float(dot3(q_vec, hkl_nphi) / (norm(q_vec) * norm(hkl_nphi))))
+            )
         except AssertionError:
             return 0, (0, 0, 0)
         return degrees(miscut), (axis[0, 0], axis[1, 0], axis[2, 0])
@@ -1322,17 +1339,14 @@ class UBCalculation:
             )
         wl = 12.39842 / en
         d = self.crystal.get_hkl_plane_distance(hkl)
-        if wl > (2 * d):
-            raise ValueError(
-                "Reflection un-reachable as wavelength (%f) is more than twice\n"
-                "the plane distance (%f)" % (wl, d)
-            )
         try:
-            return 2.0 * asin(wl / (d * 2))
-        except ValueError as e:
-            raise ValueError(
-                f"asin(wl / (d * 2) with wl={wl:f} and d={d:f}: " + e.args[0]
+            sin_theta = bound(wl / (d * 2))
+        except AssertionError:
+            raise DiffcalcException(
+                f"Reflection unreachable as wavelength {wl} is more than twice\n"
+                f"the plane distance {d}."
             )
+        return 2.0 * asin(sin_theta)
 
     def _rescale_unit_cell(
         self, hkl: Tuple[float, float, float], pos: Position, wavelength: float
@@ -1345,7 +1359,7 @@ class UBCalculation:
         Parameters
         ----------
         hkl: Tuple[float, float, float]
-            Reflection mille indices.
+            Reflection miller indices.
         pos: Position
             Diffractometer position object.
 
@@ -1357,7 +1371,7 @@ class UBCalculation:
         q_vec = get_q_phi(pos)
         q_hkl = norm(q_vec) / wavelength
         d_hkl = self.crystal.get_hkl_plane_distance(hkl)
-        sc = 1 / (q_hkl * d_hkl)
+        sc = float(1 / (q_hkl * d_hkl))
         name, a1, a2, a3, alpha1, alpha2, alpha3 = self.crystal.get_lattice()
         if abs(sc - 1.0) < SMALL:
             return None, None
@@ -1375,3 +1389,56 @@ class UBCalculation:
             alpha2,
             alpha3,
         )
+
+    @property
+    def asdict(self) -> Dict[str, Any]:
+        """Serialise the object into a JSON compatible dictionary.
+
+        Returns
+        -------
+        Dict[str, Any]
+            Dictionary containing properties of this class. Can
+            be unpacked to recreate this object using fromdict
+            class method below.
+
+        """
+        return {
+            "name": self.name,
+            "crystal": self.crystal.asdict if self.crystal is not None else None,
+            "reflist": self.reflist.asdict,
+            "orientlist": self.orientlist.asdict,
+            "reference": self.reference.asdict,
+            "surface": self.surface.asdict,
+            "u_matrix": self.U.tolist() if self.U is not None else None,
+            "ub_matrix": self.UB.tolist() if self.UB is not None else None,
+        }
+
+    @classmethod
+    def fromdict(cls, data: Dict[str, Any]) -> "UBCalculation":
+        """Construct UBCalculation instance from a JSON compatible dictionary.
+
+        Parameters
+        ----------
+        data: Dict[str, Any]
+            Dictionary containing properties of this class, must have the
+            equivalent structure to the asdict property.
+
+        Returns
+        -------
+        UBCalculation
+            Instance of this class created from the dictionary.
+
+        """
+        ubcalc = cls(data["name"])
+        ubcalc.crystal = (
+            Crystal(**data["crystal"]) if data["crystal"] is not None else None
+        )
+        ubcalc.reflist = ReflectionList.fromdict(data["reflist"])
+        ubcalc.orientlist = OrientationList.fromdict(data["orientlist"])
+        ubcalc.reference = ReferenceVector(**data["reference"])
+        ubcalc.surface = ReferenceVector(**data["surface"])
+        ubcalc.U = np.array(data["u_matrix"]) if data["u_matrix"] is not None else None
+        ubcalc.UB = (
+            np.array(data["ub_matrix"]) if data["ub_matrix"] is not None else None
+        )
+        return ubcalc
