@@ -4,7 +4,7 @@ A module defining crystal lattice class and auxiliary methods for calculating
 crystal plane geometric properties.
 """
 from math import acos, cos, degrees, pi, radians, sin, sqrt
-from typing import List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 
 import numpy as np
 from diffcalc.util import allnum, angle_between_vectors, zero_round
@@ -56,7 +56,7 @@ class Crystal:
         Parameters
         ----------
         name: str
-            Crystal name
+            Crystal name.
         system: Optional[float], default = None
             Crystal lattice type.
         a: Optional[float], default = None
@@ -103,7 +103,7 @@ class Crystal:
     def __str__(self) -> str:
         """Represent the crystal lattice information as a string.
 
-        Retruns
+        Returns
         -------
         str
             Crystal lattice information string.
@@ -192,7 +192,7 @@ class Crystal:
         b2 = 2 * pi * a1 * a3 * sin(alpha2) / volume
         b3 = 2 * pi * a1 * a2 * sin(alpha3) / volume
 
-        # Calculate the BMatrix from the direct and reciprical parameters.
+        # Calculate the BMatrix from the direct and reciprocal parameters.
         # Reference: Busang and Levy (1967)
         self.B = np.array(
             [
@@ -368,18 +368,45 @@ class Crystal:
         Parameters
         ----------
         hkl1: Tuple[float, float, float]
-            Miller indices of the first lattice plane
+            Miller indices of the first lattice plane.
         hkl2: Tuple[float, float, float]
-            Miller indices of the second lattice plane
+            Miller indices of the second lattice plane.
 
         Returns
         -------
         float
             The angle between the crystal lattice planes.
         """
-        hkl1 = np.array([hkl1]).T
-        hkl2 = np.array([hkl2]).T
-        nphi1 = self.B @ hkl1
-        nphi2 = self.B @ hkl2
+        hkl1_transpose = np.array([hkl1]).T
+        hkl2_transpose = np.array([hkl2]).T
+        nphi1 = self.B @ hkl1_transpose
+        nphi2 = self.B @ hkl2_transpose
         angle = angle_between_vectors(nphi1, nphi2)
         return angle
+
+    @property
+    def asdict(self) -> Dict[str, Any]:
+        """Serialise the crystal into a JSON compatible dictionary.
+
+        Note, because the class automatically assumes all angles are
+        in degrees, the returned angles alpha, beta and gamma are given
+        in degrees such that the dictionary can be directly unpacked as is.
+
+        Returns
+        -------
+        Dict[str, Any]
+            Dictionary containing properties of crystal class. Can
+            be directly unpacked to recreate Crystal object, i.e.
+            Crystal(**returned_dict).
+
+        """
+        return {
+            "name": self.name,
+            "system": self.system,
+            "a": self.a1,
+            "b": self.a2,
+            "c": self.a3,
+            "alpha": degrees(self.alpha1),
+            "beta": degrees(self.alpha2),
+            "gamma": degrees(self.alpha3),
+        }
