@@ -1,6 +1,6 @@
 """Module providing objects for working with reference reflections and orientations."""
 import dataclasses
-from typing import List, Tuple, Union
+from typing import Any, Dict, List, Tuple, Union
 
 from diffcalc.hkl.geometry import Position
 
@@ -66,6 +66,47 @@ class Reflection:
         h, k, l, pos, en, tag = dataclasses.astuple(self)
         return (h, k, l), pos.astuple, en, tag
 
+    @property
+    def asdict(self) -> Dict[str, Any]:
+        """Serialise the object into a JSON compatible dictionary.
+
+        Returns
+        -------
+        Dict[str, Any]
+            Dictionary containing properties of this class. Can
+            be unpacked to recreate the object using fromdict
+            class method.
+
+        """
+        class_info = self.__dict__.copy()
+        class_info["pos"] = self.pos.asdict
+        return class_info
+
+    @classmethod
+    def fromdict(cls, data: Dict[str, Any]) -> "Reflection":
+        """Construct Reflection instance from a JSON compatible dictionary.
+
+        Parameters
+        ----------
+        data: Dict[str, Any]
+            Dictionary containing properties of reflection class, must have the
+            equivalent structure of asdict property above.
+
+        Returns
+        -------
+        Reflection
+            Instance of this class created from the dictionary.
+
+        """
+        return cls(
+            data["h"],
+            data["k"],
+            data["l"],
+            Position(**data["pos"]),
+            data["energy"],
+            data["tag"],
+        )
+
 
 class ReflectionList:
     """Class containing collection of reference reflections.
@@ -87,7 +128,7 @@ class ReflectionList:
         Parameters
         ----------
         tag : str
-            identifying tag for the reflection
+            Identifying tag for the reflection.
 
         Returns
         -------
@@ -113,9 +154,9 @@ class ReflectionList:
         Parameters
         ----------
         hkl : Tuple[float, float, float]
-            Miller indices of the reflection
+            Miller indices of the reflection.
         pos: Position
-            Object representing diffractometer angles
+            Object representing diffractometer angles.
         energy : float
             Energy of the x-ray beam.
         tag : str
@@ -138,9 +179,9 @@ class ReflectionList:
         Parameters
         ----------
         idx : Union[str, int]
-            Index or tag of the reflection to be changed
+            Index or tag of the reflection to be changed.
         hkl : Tuple[float,float,float]
-            Miller indices of the reflection
+            Miller indices of the reflection.
         position: Position
             Object representing diffractometer angles.
         energy : float
@@ -167,7 +208,7 @@ class ReflectionList:
     def get_reflection(self, idx: Union[str, int]) -> Reflection:
         """Get a reference reflection.
 
-        Get aon object representing reference reflection.
+        Get an object representing reference reflection.
 
         Parameters
         ----------
@@ -177,7 +218,7 @@ class ReflectionList:
         Returns
         -------
         Reflection
-            Object representing reference reflection
+            Object representing reference reflection.
 
         Raises
         ------
@@ -290,6 +331,39 @@ class ReflectionList:
             lines.append(fmt % values)
         return lines
 
+    @property
+    def asdict(self) -> List[Dict[str, Any]]:
+        """Serialise the object into a JSON compatible dictionary.
+
+        Returns
+        -------
+        Dict[str, Any]
+            Dictionary containing properties of this class. Can
+            be unpacked to recreate this object using fromdict
+            class method below.
+
+        """
+        return [ref.asdict for ref in self.reflections]
+
+    @classmethod
+    def fromdict(cls, data: List[Dict[str, Any]]) -> "ReflectionList":
+        """Construct ReflectionList instance from a JSON compatible dictionary.
+
+        Parameters
+        ----------
+        data: Dict[str, Any]
+            Dictionary containing properties of this class, must have the
+            equivalent structure of asdict property above.
+
+        Returns
+        -------
+        ReflectionList
+            Instance of this class created from the dictionary.
+
+        """
+        reflections = [Reflection.fromdict(each_ref) for each_ref in data]
+        return cls(reflections)
+
 
 @dataclasses.dataclass
 class Orientation:
@@ -358,6 +432,49 @@ class Orientation:
         h, k, l, x, y, z, pos, tag = dataclasses.astuple(self)
         return (h, k, l), (x, y, z), pos.astuple, tag
 
+    @property
+    def asdict(self) -> Dict[str, Any]:
+        """Serialise the object into a JSON compatible dictionary.
+
+        Returns
+        -------
+        Dict[str, Any]
+            Dictionary containing properties of this class. Can
+            be unpacked to recreate this object using fromdict
+            class method below.
+
+        """
+        class_info = self.__dict__.copy()
+        class_info["pos"] = self.pos.asdict
+        return class_info
+
+    @classmethod
+    def fromdict(cls, data: Dict[str, Any]) -> "Orientation":
+        """Construct Orientation instance from a JSON compatible dictionary.
+
+        Parameters
+        ----------
+        data: Dict[str, Any]
+            Dictionary containing properties of this class, must have the
+            equivalent structure to the asdict property.
+
+        Returns
+        -------
+        Orientation
+            Instance of this class created from the dictionary.
+
+        """
+        return cls(
+            data["h"],
+            data["k"],
+            data["l"],
+            data["x"],
+            data["y"],
+            data["z"],
+            Position(**data["pos"]),
+            data["tag"],
+        )
+
 
 class OrientationList:
     """Class containing collection of reference orientations.
@@ -379,7 +496,7 @@ class OrientationList:
         Parameters
         ----------
         tag : str
-            identifying tag for the orientation
+            Identifying tag for the orientation
 
         Returns
         -------
@@ -416,7 +533,7 @@ class OrientationList:
         position: Position
             Object representing diffractometer position.
         tag : str
-            identifying tag for the orientation.
+            Identifying tag for the orientation.
         """
         if isinstance(pos, Position):
             self.orientations += [Orientation(*hkl, *xyz, pos, tag)]
@@ -499,7 +616,7 @@ class OrientationList:
         Parameters
         ----------
         idx : Union[str, int]
-            Index or tag of the deteled orientation.
+            Index or tag of the deleted orientation.
 
         Raises
         ------
@@ -549,7 +666,7 @@ class OrientationList:
         Returns
         -------
         int
-            Number of reference orientationss.
+            Number of reference orientations.
         """
         return len(self.orientations)
 
@@ -595,3 +712,36 @@ class OrientationList:
             values = (n, h, k, l, x, y, z) + angles + (tag,)
             lines.append(str_format % values)
         return lines
+
+    @property
+    def asdict(self) -> List[Dict[str, Any]]:
+        """Serialise the object into a JSON compatible dictionary.
+
+        Returns
+        -------
+        Dict[str, Any]
+            Dictionary containing properties of this class. Can
+            be unpacked to recreate this object using fromdict
+            class method below.
+
+        """
+        return [orient.asdict for orient in self.orientations]
+
+    @classmethod
+    def fromdict(cls, data: List[Dict[str, Any]]) -> "OrientationList":
+        """Construct OrientationList instance from a JSON compatible dictionary.
+
+        Parameters
+        ----------
+        data: Dict[str, Any]
+            Dictionary containing properties of this class, must have the
+            equivalent structure to the asdict property.
+
+        Returns
+        -------
+        OrientationList
+            Instance of this class created from the dictionary.
+
+        """
+        orientations = [Orientation.fromdict(each_orient) for each_orient in data]
+        return cls(orientations)
