@@ -16,11 +16,11 @@
 # along with Diffcalc.  If not, see <http://www.gnu.org/licenses/>.
 ###
 
-import math
-from math import degrees
+from math import degrees, isnan, pi
 from unittest.mock import Mock
 
 from diffcalc.hkl.calc import HklCalculation
+from diffcalc.hkl.constraints import Constraints
 from diffcalc.hkl.geometry import Position
 from diffcalc.ub.calc import UBCalculation
 from diffcalc.util import I
@@ -33,12 +33,39 @@ y = array([[0], [1], [0]])
 z = array([[0], [0], [1]])
 
 
-def isnan(n):
-    # math.isnan was introduced only in python 2.6 and is not in Jython (2.5.2)
-    try:
-        return math.isnan(n)
-    except AttributeError:
-        return n != n  # for Jython
+class TestPosition:
+    def test_compare_str(self):
+        # Test the compare method
+        pos1 = Position(1, 2, 3, 4, 5, 6)
+        pos2 = Position(1.1, 2.1, 3.1, 4.1, 5.1, 6.1)
+
+        assert pos1 == pos1
+        assert pos1 != pos2
+
+        pos3 = Position(1.1234, 2.3456, 3.4567, 4.5678, 5.6789, 6.7891)
+        assert (
+            str(pos3)
+            == "Position(mu: 1.1234, delta: 2.3456, nu: 3.4567, eta: 4.5678, chi: 5.6789, phi: 6.7891)"
+        )
+
+        pos4 = Position(
+            pi / 1.0, pi / 2.0, pi / 3.0, pi / 4.0, pi / 5.0, pi / 6.0, indegrees=False
+        )
+        assert (
+            str(pos4)
+            == f"Position(mu: {degrees(pi / 1.0):.4f}, delta: {degrees(pi / 2.0):.4f}, nu: {degrees(pi / 3.0):.4f}, eta: {degrees(pi / 4.0):.4f}, chi: {degrees(pi / 5.0):.4f}, phi: {degrees(pi / 6.0):.4f})"
+        )
+
+    def test_getter_setter(self):
+        pos_deg = Position()
+        pos_rad = Position(indegrees=False)
+        for i, field in enumerate(pos_deg.fields, 1):
+            setattr(pos_deg, field, float(i))
+            setattr(pos_rad, field, pi / float(i))
+
+        for i, field in enumerate(pos_deg.fields, 1):
+            assert_almost_equal(getattr(pos_deg, field), float(i))
+            assert_almost_equal(getattr(pos_rad, field), pi / float(i))
 
 
 class Test_position_to_virtual_angles:
@@ -57,7 +84,10 @@ class Test_position_to_virtual_angles:
         """All in degrees"""
         pos = Position(mu=mu, delta=delta, nu=nu, eta=eta, chi=chi, phi=phi)
         calculated = self.calc.get_virtual_angles(pos, False)[name]
-        assert_almost_equal(degrees(calculated), expected)
+        if isnan(expected):
+            assert isnan(calculated)
+        else:
+            assert_almost_equal(degrees(calculated), expected)
 
     # theta
 
@@ -127,7 +157,7 @@ class Test_position_to_virtual_angles:
     # beta
 
     def test_beta0(self):
-        self.check_angle("beta", 0, delta=0, nu=0, mu=0, eta=0, chi=0, phi=0)
+        self.check_angle("beta", float("nan"), delta=0, nu=0, mu=0, eta=0, chi=0, phi=0)
 
     def test_beta1(self):
         self.check_angle("beta", 0, delta=10, nu=0, mu=0, eta=6, chi=0, phi=5)
@@ -159,7 +189,7 @@ class Test_position_to_virtual_angles:
 
     # tau
     def test_tau0(self):
-        self.check_angle("tau", 0, mu=0, delta=0, nu=0, eta=0, chi=0, phi=0)
+        self.check_angle("tau", float("nan"), mu=0, delta=0, nu=0, eta=0, chi=0, phi=0)
         # self.check_angle('tau_from_dot_product', 90, mu=0, delta=0,
         # nu=0, eta=0, chi=0, phi=0)
 
@@ -220,3 +250,13 @@ class Test_position_to_virtual_angles:
 
     def test_psi8(self):
         self.check_angle("psi", 88, mu=0, delta=0.001, nu=0, eta=90, chi=-2, phi=0)
+
+    def test_serialisation(self):
+        hklCalc = HklCalculation(
+            self.ubcalc, Constraints({"delta": 1, "alpha": 2, "mu": 3})
+        )
+        hklCalc_json = hklCalc.asdict
+
+        new_hklCalc = HklCalculation.fromdict(hklCalc_json)
+
+        assert new_hklCalc.asdict == hklCalc.asdict
