@@ -25,16 +25,13 @@ from tests.diffcalc.scenarios import PosFromI16sEuler
 from tests.test_tools import eq_
 from tests.tools import matrixeq_
 
-UB1 = (
-    array(
-        (
-            (0.9996954135095477, -0.01745240643728364, -0.017449748351250637),
-            (0.01744974835125045, 0.9998476951563913, -0.0003045864904520898),
-            (0.017452406437283505, -1.1135499981271473e-16, 0.9998476951563912),
-        )
+UB1 = array(
+    (
+        (0.9996954135095477, -0.01745240643728364, -0.017449748351250637),
+        (0.01744974835125045, 0.9998476951563913, -0.0003045864904520898),
+        (0.017452406437283505, -1.1135499981271473e-16, 0.9998476951563912),
     )
-    * (2 * pi)
-)
+) * (2 * pi)
 
 EN1 = 12.39842
 REF1a = PosFromI16sEuler(1, 1, 30, 0, 60, 0)
